==> javaee-api-7.0-1-sources.jar: javax/enterprise/inject/spi/ProcessProducerMethod.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.enterprise.inject.spi;

/**
 * Fired before registering producer method.
 * 
 * @version $Rev: 1493277 $ $Date: 2013-06-15 01:05:23 +0200 (Sat, 15 Jun 2013) $
 *
 * @param <X> bean class
 * @param <T> producer return type
 */
public interface ProcessProducerMethod<X, T> extends ProcessBean<T>
{
    /**
     * Returns annotated method.
     * 
     * @return annotated method
     */
    public AnnotatedMethod<X> getAnnotatedProducerMethod();

    /**
     * Returns annotated parameter.
     * @return the {@link javax.enterprise.inject.Disposes} annotated parameter of the disposal method
     *      which fits the producer field, or <code>null</code> if there is no disposal method.
     */
    public AnnotatedParameter<X> getAnnotatedDisposedParameter();

}

==> javaee-api-8.0-4-sources.jar: javax/enterprise/inject/spi/ProcessProducerMethod.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package javax.enterprise.inject.spi;

/**
 * Fired before registering producer method.
 * 
 * @version $Rev: 1796096 $ $Date: 2017-05-24 16:27:18 -0400 (Wed, 24 May 2017) $
 *
 * @param <X> bean class
 * @param <T> producer return type
 */
public interface ProcessProducerMethod<X, T> extends ProcessBean<T>
{
    /**
     * Returns annotated method.
     * 
     * @return annotated method
     */
    AnnotatedMethod<X> getAnnotatedProducerMethod();

    /**
     * Returns annotated parameter.
     * @return the {@link javax.enterprise.inject.Disposes} annotated parameter of the disposal method
     *      which fits the producer field, or <code>null</code> if there is no disposal method.
     */
    AnnotatedParameter<X> getAnnotatedDisposedParameter();

}
